@@ -124,10 +124,13 @@ def getModule(moduleName):
     """
     #Logger.printMessage('Initiation of {moduleName}'.format(moduleName=moduleName), debug_module=True)
 
+    print(__modulesLoadesThreadNames__)
+
     for m in __modules_loaded__:
         if moduleName in m:
             if not 'ht_' in moduleName:
                 moduleName = 'ht_{m}'.format(m=moduleName)
+            __modulesLoadesThreadNames__.remove(moduleName)
             sentence = 'modules.{category}.{mod}.{moduleName}.StartModule()'.format(category=m.split('.')[1], mod='_'.join(moduleName.split('_')[1:]), moduleName=moduleName)
             return eval(sentence)
 
@@ -136,9 +139,7 @@ def getModule(moduleName):
         for worker in getWorkers():
             if moduleName in worker:
                 __sleep(0.1)
-                getModule(moduleName)
-                break
-        __modulesLoadesThreadNames__.remove(moduleName)
+                return getModule(moduleName)
 
     Logger.printMessage('Looks like {mod} is not loaded on HackingTools. Look the first import in log. You could have some error in your code :)'.format(mod=moduleName), is_error=True)
 
